summaryrefslogtreecommitdiff
path: root/Source/UnitTests/Common/x64EmitterTest.cpp
diff options
context:
space:
mode:
authorShawn Hoffman <godisgovernment@gmail.com>2022-04-26 23:05:13 -0700
committerShawn Hoffman <godisgovernment@gmail.com>2022-04-27 15:06:04 -0700
commitcad1f2735c2b2f9951f3a393ce179dc4bae5f847 (patch)
treef1a9581e060b628ec79c9f41ae0ab3dbd20122e7 /Source/UnitTests/Common/x64EmitterTest.cpp
parentdde2f7e637eba4b998477776ebb46c02d330c00c (diff)
msvc: disable optimizations for x64EmitterTest.cpp
40s -> 5s speedup
Diffstat (limited to 'Source/UnitTests/Common/x64EmitterTest.cpp')
-rw-r--r--Source/UnitTests/Common/x64EmitterTest.cpp9
1 files changed, 9 insertions, 0 deletions
diff --git a/Source/UnitTests/Common/x64EmitterTest.cpp b/Source/UnitTests/Common/x64EmitterTest.cpp
index d374391876..439ac5e9d6 100644
--- a/Source/UnitTests/Common/x64EmitterTest.cpp
+++ b/Source/UnitTests/Common/x64EmitterTest.cpp
@@ -19,6 +19,11 @@
#include "Common/StringUtil.h"
#include "Common/x64Emitter.h"
+#ifdef _MSC_VER
+// This file is extremely slow to optimize (40s on amd 3990x), so just disable optimizations
+#pragma optimize("", off)
+#endif
+
namespace Gen
{
struct NamedReg
@@ -1243,3 +1248,7 @@ FMA4_TEST(VFMADDSUB, P, true)
FMA4_TEST(VFMSUBADD, P, true)
} // namespace Gen
+
+#ifdef _MSC_VER
+#pragma optimize("", on)
+#endif